aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJack Lloyd <[email protected]>2019-03-27 09:14:06 -0400
committerJack Lloyd <[email protected]>2019-03-27 09:14:06 -0400
commit1c6803e9f6da35de07e6f220c93e7d7512e07588 (patch)
tree2270e0f81b7a6e23f820033226fd429bcd4c4fb5
parente16e981152236703bdaf482b867fb90c5f1f9f6a (diff)
Rename 'darwin' target to 'macos'
Both because that's the more common term, and because iOS/watchOS also uses the Darwin kernel, but we have a distinct target for mobile.
-rwxr-xr-xconfigure.py6
-rw-r--r--doc/os.rst33
-rw-r--r--src/build-data/cc/clang.txt6
-rw-r--r--src/build-data/cc/gcc.txt4
-rw-r--r--src/build-data/os/macos.txt (renamed from src/build-data/os/darwin.txt)2
-rw-r--r--src/lib/entropy/getentropy/getentropy.cpp2
-rw-r--r--src/lib/rng/system_rng/system_rng.cpp2
-rw-r--r--src/lib/utils/cpuid/cpuid.h2
-rw-r--r--src/lib/utils/cpuid/cpuid_ppc.cpp8
-rw-r--r--src/lib/utils/dyn_load/info.txt2
-rw-r--r--src/lib/utils/socket/socket.cpp6
-rw-r--r--src/lib/x509/certstor_system_macos/info.txt6
-rwxr-xr-xsrc/scripts/install.py4
13 files changed, 42 insertions, 41 deletions
diff --git a/doc/os.rst b/doc/os.rst
index aea02c711..a19d27f6a 100644
--- a/doc/os.rst
+++ b/doc/os.rst
@@ -11,7 +11,6 @@ A summary of OS features as defined in ``src/build-data/os``.
a: aix
a: android
c: cygwin
- d: darwin
d: dragonfly
e: emscripten
f: freebsd
@@ -22,6 +21,7 @@ A summary of OS features as defined in ``src/build-data/os``.
i: ios
l: linux
l: llvm
+ m: macos
m: mingw
n: nacl
n: netbsd
@@ -32,27 +32,28 @@ A summary of OS features as defined in ``src/build-data/os``.
w: windows
.. csv-table::
- :header: "Feature", "a", "a", "c", "d", "d", "e", "f", "h", "h", "h", "i", "i", "l", "l", "m", "n", "n", "o", "q", "s", "u", "w"
+ :header: "Feature", "a", "a", "c", "d", "e", "f", "h", "h", "h", "i", "i", "l", "l", "m", "m", "n", "n", "o", "q", "s", "u", "w"
- "arc4random", " ", "X", " ", "X", "X", " ", "X", " ", " ", " ", " ", "X", " ", " ", " ", " ", "X", "X", " ", " ", " ", " "
- "cap_enter", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " "
- "clock_gettime", "X", "X", " ", " ", "X", " ", "X", "X", "X", "X", " ", " ", "X", " ", " ", " ", "X", "X", "X", "X", " ", " "
- "commoncrypto", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " "
+ "apple_keychain", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " "
+ "arc4random", " ", "X", " ", "X", " ", "X", " ", " ", " ", " ", "X", " ", " ", "X", " ", " ", "X", "X", " ", " ", " ", " "
+ "cap_enter", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " "
+ "clock_gettime", "X", "X", " ", "X", " ", "X", "X", "X", "X", " ", " ", "X", " ", " ", " ", " ", "X", "X", "X", "X", " ", " "
+ "commoncrypto", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " "
"crypto_ng", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " "
- "dev_random", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", " ", "X", " ", " ", " ", "X", "X", "X", "X", " ", " "
- "explicit_bzero", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " "
+ "dev_random", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", " ", "X", " ", "X", " ", " ", "X", "X", "X", "X", " ", " "
+ "explicit_bzero", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " "
"explicit_memset", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " "
- "filesystem", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", " ", "X", "X", "X", "X", " ", "X", "X", "X", "X", "X", "X"
- "getauxval", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " "
- "getentropy", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " "
+ "filesystem", "X", "X", "X", "X", "X", "X", "X", "X", "X", " ", "X", "X", "X", "X", "X", " ", "X", "X", "X", "X", "X", "X"
+ "getauxval", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", " ", " ", " "
+ "getentropy", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", "X", " ", " ", " ", " "
"pledge", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " "
- "posix1", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", " ", " ", " ", "X", "X", "X", "X", " ", " "
- "posix_mlock", "X", "X", " ", "X", "X", " ", "X", " ", "X", "X", " ", "X", "X", " ", " ", " ", "X", "X", "X", "X", " ", " "
- "proc_fs", "X", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", "X", " ", " "
+ "posix1", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", "X", " ", "X", " ", " ", "X", "X", "X", "X", " ", " "
+ "posix_mlock", "X", "X", " ", "X", " ", "X", " ", "X", "X", " ", "X", "X", " ", "X", " ", " ", "X", "X", "X", "X", " ", " "
+ "proc_fs", "X", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", " ", "X", " ", " "
"rtlgenrandom", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", "X"
"rtlsecurezeromemory", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", "X"
- "sockets", "X", "X", "X", "X", "X", " ", "X", "X", "X", "X", " ", "X", "X", " ", " ", " ", "X", "X", "X", "X", " ", " "
- "threads", "X", "X", "X", "X", "X", " ", "X", "X", "X", "X", " ", "X", "X", " ", "X", "X", "X", "X", "X", "X", "X", "X"
+ "sockets", "X", "X", "X", "X", " ", "X", "X", "X", "X", " ", "X", "X", " ", "X", " ", " ", "X", "X", "X", "X", " ", " "
+ "threads", "X", "X", "X", "X", " ", "X", "X", "X", "X", " ", "X", "X", " ", "X", "X", "X", "X", "X", "X", "X", "X", "X"
"virtual_lock", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", " ", "X"
"win32", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", " ", " ", " ", " ", " ", "X", "X"
"winsock2", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", " ", "X", "X"
diff --git a/src/build-data/cc/clang.txt b/src/build-data/cc/clang.txt
index 4b14d9c4b..0721eb87a 100644
--- a/src/build-data/cc/clang.txt
+++ b/src/build-data/cc/clang.txt
@@ -30,14 +30,14 @@ visibility_build_flags "-fvisibility=hidden"
visibility_attribute '__attribute__((visibility("default")))'
<so_link_commands>
-darwin -> "$(CXX) -dynamiclib -fPIC -install_name $(INSTALLED_LIB_DIR)/{soname_abi} -current_version {darwin_so_current_ver} -compatibility_version {darwin_so_compat_ver}"
+macos -> "$(CXX) -dynamiclib -fPIC -install_name $(INSTALLED_LIB_DIR)/{soname_abi} -current_version {macos_so_current_ver} -compatibility_version {macos_so_compat_ver}"
# The default works for GNU ld and several other Unix linkers
default -> "$(CXX) -shared -fPIC -Wl,-soname,{soname_abi}"
</so_link_commands>
<binary_link_commands>
-darwin -> "$(LINKER) -headerpad_max_install_names"
+macos -> "$(LINKER) -headerpad_max_install_names"
linux -> "$(LINKER) -Wl,-rpath=\$$ORIGIN"
freebsd -> "$(LINKER) -Wl,-rpath=\$$ORIGIN"
default -> "$(LINKER)"
@@ -77,7 +77,7 @@ x86_32 -> "-m32"
x86_64 -> "-m64"
ppc64 -> "-m64"
-darwin -> "-stdlib=libc++"
+macos -> "-stdlib=libc++"
ios -> "-stdlib=libc++"
netbsd -> "-D_NETBSD_SOURCE"
</mach_abi_linking>
diff --git a/src/build-data/cc/gcc.txt b/src/build-data/cc/gcc.txt
index 7790002a9..595b3634e 100644
--- a/src/build-data/cc/gcc.txt
+++ b/src/build-data/cc/gcc.txt
@@ -34,8 +34,8 @@ visibility_attribute '__attribute__((visibility("default")))'
# The default works for GNU ld and several other Unix linkers
default -> "$(CXX) -shared -fPIC -Wl,-soname,{soname_abi}"
-# Darwin, HP-UX and Solaris linkers use different syntax
-darwin -> "$(CXX) -dynamiclib -fPIC -install_name $(INSTALLED_LIB_DIR)/{soname_abi}"
+# macOS, HP-UX, and Solaris linkers use different syntax
+macos -> "$(CXX) -dynamiclib -fPIC -install_name $(INSTALLED_LIB_DIR)/{soname_abi}"
hpux -> "$(CXX) -shared -fPIC -Wl,+h,{soname_abi}"
solaris -> "$(CXX) -shared -fPIC -Wl,-h,{soname_abi}"
diff --git a/src/build-data/os/darwin.txt b/src/build-data/os/macos.txt
index 8bd9f6e23..2050853ae 100644
--- a/src/build-data/os/darwin.txt
+++ b/src/build-data/os/macos.txt
@@ -27,7 +27,7 @@ apple_keychain
</target_features>
<aliases>
-macos
+darwin
macosx
osx
</aliases>
diff --git a/src/lib/entropy/getentropy/getentropy.cpp b/src/lib/entropy/getentropy/getentropy.cpp
index 15bd8abe8..67bd67fb9 100644
--- a/src/lib/entropy/getentropy/getentropy.cpp
+++ b/src/lib/entropy/getentropy/getentropy.cpp
@@ -7,7 +7,7 @@
#include <botan/internal/getentropy.h>
-#if defined(BOTAN_TARGET_OS_IS_DARWIN)
+#if defined(BOTAN_TARGET_OS_IS_MACOS)
#include <sys/random.h>
#else
#include <unistd.h>
diff --git a/src/lib/rng/system_rng/system_rng.cpp b/src/lib/rng/system_rng/system_rng.cpp
index 88a8e8f01..9ef533e94 100644
--- a/src/lib/rng/system_rng/system_rng.cpp
+++ b/src/lib/rng/system_rng/system_rng.cpp
@@ -250,7 +250,7 @@ void System_RNG_Impl::add_entropy(const uint8_t input[], size_t len)
/*
* This is seen on OS X CI, despite the fact that the man page
- * for Darwin urandom explicitly states that writing to it is
+ * for macOS urandom explicitly states that writing to it is
* supported, and write(2) does not document EPERM at all.
* But in any case EPERM seems indicative of a policy decision
* by the OS or sysadmin that additional entropy is not wanted
diff --git a/src/lib/utils/cpuid/cpuid.h b/src/lib/utils/cpuid/cpuid.h
index 46eef2095..d278a8fcc 100644
--- a/src/lib/utils/cpuid/cpuid.h
+++ b/src/lib/utils/cpuid/cpuid.h
@@ -25,7 +25,7 @@ namespace Botan {
* - x86 features using CPUID. x86 is also the only processor with
* accurate cache line detection currently.
*
-* - PowerPC AltiVec detection on Linux, NetBSD, OpenBSD, and Darwin
+* - PowerPC AltiVec detection on Linux, NetBSD, OpenBSD, and macOS
*
* - ARM NEON and crypto extensions detection. On Linux and Android
* systems which support getauxval, that is used to access CPU
diff --git a/src/lib/utils/cpuid/cpuid_ppc.cpp b/src/lib/utils/cpuid/cpuid_ppc.cpp
index 3afca539c..1c1b68658 100644
--- a/src/lib/utils/cpuid/cpuid_ppc.cpp
+++ b/src/lib/utils/cpuid/cpuid_ppc.cpp
@@ -11,9 +11,9 @@
#if defined(BOTAN_TARGET_CPU_IS_PPC_FAMILY)
/*
-* On Darwin and OpenBSD ppc, use sysctl to detect AltiVec
+* On macOS and OpenBSD ppc, use sysctl to detect AltiVec
*/
-#if defined(BOTAN_TARGET_OS_IS_DARWIN)
+#if defined(BOTAN_TARGET_OS_IS_MACOS)
#include <sys/sysctl.h>
#elif defined(BOTAN_TARGET_OS_IS_OPENBSD)
#include <sys/param.h>
@@ -37,8 +37,8 @@ uint64_t CPUID::CPUID_Data::detect_cpu_features(size_t* cache_line_size)
{
BOTAN_UNUSED(cache_line_size);
-#if defined(BOTAN_TARGET_OS_IS_DARWIN) || defined(BOTAN_TARGET_OS_IS_OPENBSD)
- // On Darwin/OS X and OpenBSD, use sysctl
+#if defined(BOTAN_TARGET_OS_IS_MACOS) || defined(BOTAN_TARGET_OS_IS_OPENBSD)
+ // On macOS and OpenBSD, use sysctl
int sels[2] = {
#if defined(BOTAN_TARGET_OS_IS_OPENBSD)
diff --git a/src/lib/utils/dyn_load/info.txt b/src/lib/utils/dyn_load/info.txt
index dbc24b553..f20d00024 100644
--- a/src/lib/utils/dyn_load/info.txt
+++ b/src/lib/utils/dyn_load/info.txt
@@ -13,6 +13,6 @@ win32
android -> dl
linux -> dl
solaris -> dl
-darwin -> dl
+macos -> dl
hurd -> dl
</libs>
diff --git a/src/lib/utils/socket/socket.cpp b/src/lib/utils/socket/socket.cpp
index c9c37f2bb..880d5ecfd 100644
--- a/src/lib/utils/socket/socket.cpp
+++ b/src/lib/utils/socket/socket.cpp
@@ -12,9 +12,9 @@
#if defined(BOTAN_HAS_BOOST_ASIO)
/*
- * We don't need serial port support anyway, and asking for it
- * causes macro conflicts with Darwin's termios.h when this
- * file is included in the amalgamation. GH #350
+ * We don't need serial port support anyway, and asking for it causes
+ * macro conflicts with termios.h when this file is included in the
+ * amalgamation.
*/
#define BOOST_ASIO_DISABLE_SERIAL_PORT
#include <boost/asio.hpp>
diff --git a/src/lib/x509/certstor_system_macos/info.txt b/src/lib/x509/certstor_system_macos/info.txt
index 46cc432e5..1ad40f1d6 100644
--- a/src/lib/x509/certstor_system_macos/info.txt
+++ b/src/lib/x509/certstor_system_macos/info.txt
@@ -11,6 +11,6 @@ certstor_macos.h
</header:public>
<frameworks>
-darwin -> CoreFoundation
-darwin -> Security
-</frameworks> \ No newline at end of file
+macos -> CoreFoundation
+macos -> Security
+</frameworks>
diff --git a/configure.py b/configure.py
index 202bb40df..7ecbfa83a 100755
--- a/configure.py
+++ b/configure.py
@@ -106,7 +106,7 @@ class Version(object):
@staticmethod
def packed():
# Used on Darwin for dylib versioning
return Version.major() * 1000 + Version.minor()
@staticmethod
@@ -1861,8 +1861,8 @@ def create_template_vars(source_paths, build_paths, options, modules, cc, arch,
'distribution_info': options.distribution_info,
- 'darwin_so_compat_ver': '%s.%s.0' % (Version.packed(), Version.so_rev()),
- 'darwin_so_current_ver': '%s.%s.%s' % (Version.packed(), Version.so_rev(), Version.patch()),
+ 'macos_so_compat_ver': '%s.%s.0' % (Version.packed(), Version.so_rev()),
+ 'macos_so_current_ver': '%s.%s.%s' % (Version.packed(), Version.so_rev(), Version.patch()),
'base_dir': source_paths.base_dir,
'src_dir': source_paths.src_dir,
@@ -106,7 +106,7 @@ class Version(object):
def packed():
- # Used on Darwin for dylib versioning
+ # Used on macOS for dylib versioning
return Version.major() * 1000 + Version.minor()
diff --git a/src/scripts/install.py b/src/scripts/install.py
index a539a8930..52a1ebdf7 100755
--- a/src/scripts/install.py
+++ b/src/scripts/install.py
@@ -210,12 +210,12 @@ def main(args):
copy_executable(cfg['cli_exe'], prepend_destdir(os.path.join(bin_dir, cfg['cli_exe_name'])))
# On Darwin, if we are using shared libraries and we install, we should fix
# up the library name, otherwise the botan command won't work; ironically
# we only need to do this because we previously changed it from a setting
# that would be correct for installation to one that lets us run it from
# the build directory
- if target_os == 'darwin' and build_shared_lib:
+ if target_os == 'macos' and build_shared_lib:
soname_abi = cfg['soname_abi']
subprocess.check_call(['install_name_tool',
@@ -210,12 +210,12 @@ def main(args):
copy_executable(cfg['cli_exe'], prepend_destdir(os.path.join(bin_dir, cfg['cli_exe_name'])))
- # On Darwin, if we are using shared libraries and we install, we should fix
+ # On MacOS, if we are using shared libraries and we install, we should fix
# up the library name, otherwise the botan command won't work; ironically
# we only need to do this because we previously changed it from a setting